@@ -11,11 +11,20 @@ export const sidebarItems: ISidebarSection[] = [
   { href: "/docs/getting-started", text: "Getting Started" },
   { href: "/docs/install", text: "Installation" },
   { href: "/docs/how-it-works", text: "How it Works" },
+  {
+    text: "Guides",
+    links: [
+      { text: "Configuring Builds", href: "/docs/guides/configuring-builds" },
+    ],
+  },
   {
     text: "Configuration",
     links: [
-      { text: "Configuration File", href: "/docs/configuration/file" },
-      { text: "Environment", href: "/docs/configuration/environment" },
+      { text: "File", href: "/docs/configuration/file" },
+      {
+        text: "Environment",
+        href: "/docs/configuration/environment",
+      },
       { text: "Procfile", href: "/docs/configuration/procfile" },
       { text: "Caching", href: "/docs/configuration/caching" },
     ],
@@ -24,20 +33,21 @@ export const sidebarItems: ISidebarSection[] = [
   {
     text: "Language Support",
     links: [
+      { href: "/docs/providers/clojure", text: "Clojure" },
+      { href: "/docs/providers/cobol", text: "Cobol" },
       { href: "/docs/providers/crystal", text: "Crystal" },
       { href: "/docs/providers/csharp", text: "C#/.NET" },
       { href: "/docs/providers/dart", text: "Dart" },
       { href: "/docs/providers/deno", text: "Deno" },
+      { href: "/docs/providers/elixir", text: "Elixir" },
       { href: "/docs/providers/fsharp", text: "F#" },
       { href: "/docs/providers/go", text: "Go" },
       { href: "/docs/providers/haskell", text: "Haskell" },
       { href: "/docs/providers/java", text: "Java" },
-      { href: "/docs/providers/clojure", text: "Clojure" },
       { href: "/docs/providers/node", text: "Node" },
       { href: "/docs/providers/php", text: "PHP" },
       { href: "/docs/providers/python", text: "Python" },
       { href: "/docs/providers/ruby", text: "Ruby" },
-      { href: "/docs/providers/elixir", text: "Elixir" },
       { href: "/docs/providers/rust", text: "Rust" },
       { href: "/docs/providers/staticfile", text: "Staticfile" },
       { href: "/docs/providers/swift", text: "Swift" },
