@@ -18,9 +18,11 @@ pub mod merge;
 pub mod phase;
 pub mod pretty_print;
 mod topological_sort;
+mod utils;
 
 pub trait PlanGenerator {
     fn generate_plan(&mut self, app: &App, environment: &Environment) -> Result<BuildPlan>;
+    fn get_plan_providers(&self, app: &App, environment: &Environment) -> Result<Vec<String>>;
 }
 
 #[serde_with::skip_serializing_none]
@@ -64,6 +66,18 @@ impl BuildPlan {
         Ok(plan)
     }
 
+    pub fn to_toml(&self) -> Result<String> {
+        let mut plan = self.clone();
+        plan.remove_phase_names();
+        Ok(toml::to_string_pretty(&plan)?)
+    }
+
+    pub fn to_json(&self) -> Result<String> {
+        let mut plan = self.clone();
+        plan.remove_phase_names();
+        Ok(serde_json::to_string_pretty(&plan)?)
+    }
+
     pub fn add_phase(&mut self, phase: Phase) {
         let phases = self.phases.get_or_insert(BTreeMap::default());
         phases.insert(phase.get_name(), phase);
@@ -182,6 +196,13 @@ impl BuildPlan {
         }
     }
 
+    pub fn remove_phase_names(&mut self) {
+        let phases = self.phases.get_or_insert(BTreeMap::default());
+        for (_, phase) in phases.iter_mut() {
+            phase.name = None;
+        }
+    }
+
     pub fn from_environment(env: &Environment) -> Self {
         let mut phases: Vec<Phase> = Vec::new();
 
